summaryrefslogtreecommitdiff
path: root/src/leap/bitmask/vpn/_config.py
diff options
context:
space:
mode:
authorKali Kaneko (leap communications) <kali@leap.se>2017-02-20 20:39:43 +0100
committerKali Kaneko (leap communications) <kali@leap.se>2017-02-23 00:41:25 +0100
commit25ad6f18057ad7951f74eff35afe25d220952efa (patch)
treebfcb70fde93f73f993a3ae42f7c3def73464e105 /src/leap/bitmask/vpn/_config.py
parent9d7de357a114812c0ed1e04b97ef59b41a40fa47 (diff)
[refactor] rename eip to vpn
Diffstat (limited to 'src/leap/bitmask/vpn/_config.py')
-rw-r--r--src/leap/bitmask/vpn/_config.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/leap/bitmask/vpn/_config.py b/src/leap/bitmask/vpn/_config.py
index 8ae266a1..5f10734d 100644
--- a/src/leap/bitmask/vpn/_config.py
+++ b/src/leap/bitmask/vpn/_config.py
@@ -13,8 +13,8 @@ if IS_LINUX:
'leap.bitmask.vpn.helpers.linux', 'se.leap.bitmask.bundle.policy')
-class _TempEIPConfig(object):
- """Current EIP code on bitmask depends on EIPConfig object, this temporary
+class _TempVPNConfig(object):
+ """Current VPN code on bitmask depends on VPNConfig object, this temporary
implementation helps on the transition."""
def __init__(self, flags, path, ports):
@@ -33,7 +33,7 @@ class _TempEIPConfig(object):
class _TempProviderConfig(object):
- """Current EIP code on bitmask depends on ProviderConfig object, this
+ """Current VPN code on bitmask depends on ProviderConfig object, this
temporary implementation helps on the transition."""
def __init__(self, domain, path):